@@ -21,12 +21,19 @@ class QString;
  */
 namespace KFontUtils
 {
-/** Modifiers for the adaptFontSize function */
+/**
+ * Modifiers for the adaptFontSize function
+ * @see AdaptFontSizeOptions
+ */
 enum AdaptFontSizeOption {
     NoFlags = 0x01, ///< No modifier
     DoNotAllowWordWrap = 0x02  ///< Do not use word wrapping
 };
+/**
+ * Stores a combination of #AdaptFontSizeOption values.
+ */
 Q_DECLARE_FLAGS(AdaptFontSizeOptions, AdaptFontSizeOption)
+Q_DECLARE_OPERATORS_FOR_FLAGS(AdaptFontSizeOptions)
 
 /** Helper function that calculates the biggest font size (in points) used
     drawing a centered text using word wrapping.
@@ -64,7 +71,4 @@ qreal KGUIADDONS_EXPORT adaptFontSize(QPainter &painter,
                                       AdaptFontSizeOptions flags = NoFlags);
 }
 
-Q_DECLARE_OPERATORS_FOR_FLAGS(KFontUtils::AdaptFontSizeOptions)
-
 #endif
-
